@@ -19,6 +19,26 @@ from kubernetes_asyncio.stream import WsApiClient
 from kubernetes_asyncio.stream.ws_client import WsResponse, get_websocket_url
 
 
+class WsMock:
+    def __init__(self):
+        self.iter = 0
+
+    def __aiter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        return self
+
+    async def __aenter__(self):
+        return self
+
+    async def __anext__(self):
+        self.iter += 1
+        if self.iter > 5:
+            raise StopAsyncIteration
+        return WsResponse(200, (chr(1) + 'mock').encode('utf-8'))
+
+
 class WSClientTest(TestCase):
 
     def test_websocket_client(self):
@@ -35,26 +55,6 @@ class WSClientTest(TestCase):
             self.assertEqual(get_websocket_url(url), ws_url)
 
     async def test_exec_ws(self):
-
-        class WsMock:
-            def __init__(self):
-                self.iter = 0
-
-            def __aiter__(self):
-                return self
-
-            async def __aexit__(self, exc_type, exc, tb):
-                return self
-
-            async def __aenter__(self):
-                return self
-
-            async def __anext__(self):
-                self.iter += 1
-                if self.iter > 5:
-                    raise StopAsyncIteration
-                return WsResponse(200, (chr(1) + 'mock').encode('utf-8'))
-
         mock = CoroutineMock()
         mock.RESTClientObject.return_value.pool_manager = mock
         mock.ws_connect.return_value = WsMock()
@@ -77,7 +77,35 @@ class WSClientTest(TestCase):
                     'sec-websocket-protocol': 'v4.channel.k8s.io',
                     'Accept': '*/*',
                     'User-Agent': api_client.user_agent
-                }
+                },
+                heartbeat=None
+            )
+
+    async def test_exec_ws_with_heartbeat(self):
+        mock = CoroutineMock()
+        mock.RESTClientObject.return_value.pool_manager = mock
+        mock.ws_connect.return_value = WsMock()
+        with patch('kubernetes_asyncio.client.api_client.rest', mock):
+
+            api_client = WsApiClient(heartbeat=30)
+            api_client.configuration.host = 'https://localhost'
+            ws = client.CoreV1Api(api_client=api_client)
+            resp = ws.connect_get_namespaced_pod_exec('pod', 'namespace',
+                                                      command='mock-command',
+                                                      stderr=True, stdin=False,
+                                                      stdout=True, tty=False)
+
+            ret = await resp
+            self.assertEqual(ret, 'mock' * 5)
+            mock.ws_connect.assert_called_once_with(
+                'wss://localhost/api/v1/namespaces/namespace/pods/pod/exec?'
+                'command=mock-command&stderr=True&stdin=False&stdout=True&tty=False',
+                headers={
+                    'sec-websocket-protocol': 'v4.channel.k8s.io',
+                    'Accept': '*/*',
+                    'User-Agent': api_client.user_agent
+                },
+                heartbeat=30
             )
 
 
